@@ -32,7 +32,7 @@ def main():
     (options, args) = parser.parse_args()
 
     logger = logging.getLogger()
-    hdlr = logging.StreamHandler(strm=sys.stderr)
+    hdlr = logging.StreamHandler()
     hdlr.setFormatter(logging.Formatter('%(asctime)s %(levelname)s %(message)s'))
     logger.addHandler(hdlr)
     if options.debug:
@@ -59,7 +59,7 @@ def main():
     elif options.translate:
         return showUrl(getTranslateUrl(pkginfo), logger)
     elif options.filebug:
-	args = ['ubuntu-bug']
+	args = ['apport-bug', '--tag', 'apport-lpi']
 	if options.pid:
 	    args.append(str(options.pid))
 	else: 
